@@ -18,7 +18,7 @@ sub import {
     
     # Join die
     my $message = 'Script::Sub::Import die';
-    $script = "package $package;\ndie '$message';\n" . $script;
+    $script = "package $package;\n" . $script . "BEGIN{die '$message'}\n";
     
     # Eval
     eval $script;
@@ -38,11 +38,11 @@ Script::Sub::Import - Import only subroutines from perl script
 
 =head1 VERSION
 
-Version 0.0101
+Version 0.0201
 
 =cut
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0201';
 
 
 =head1 SYNOPSIS
@@ -57,6 +57,18 @@ our $VERSION = '0.0101';
 
 This is very useful at automatic test because you can test only subroutine.
 
+If you want to import subroutines to main package, do this.
+
+    use Script::Sub::Import 'script.pl';
+
+If you want to import subroutines to specified package, do this.
+
+    use Script::Sub::Import 'script.pl' => 'Some::Package';
+    
+This module can be used from command line.
+
+    perl -MScript::Sub::Import=script.pl basic.t
+
 =head1 AUTHOR
 
 Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
